@@ -8,6 +8,8 @@ import sys
 
 import requests
 
+from lightning_app.core.constants import LIGHTNING_APPS_PUBLIC_REGISTRY, LIGHTNING_COMPONENT_PUBLIC_REGISTRY
+
 logger = logging.getLogger(__name__)
 
 
@@ -295,8 +297,16 @@ def _validate_name(name, resource_type, example):
 
 
 def _resolve_resource(registry_url, name, version_arg, resource_type):
+    gallery_entries = []
     try:
         url = requests.get(registry_url)
+        data = json.loads(url.text)
+
+        if resource_type == "app":
+            gallery_entries = [a for a in data["apps"] if a["canDownloadSourceCode"]]
+
+        elif resource_type == "component":
+            gallery_entries = data["components"]
     except requests.ConnectionError:
         m = f"""
         Network connection error, could not load list of available Lightning {resource_type}s.
@@ -306,12 +316,9 @@ def _resolve_resource(registry_url, name, version_arg, resource_type):
         sys.tracebacklimit = 0
         raise SystemError(m)
 
-    data = json.loads(url.text)
-    data = data[resource_type + "s"]
-
     entries = []
     all_versions = []
-    for x in data:
+    for x in gallery_entries:
         if name == x["name"]:
             entries.append(x)
             all_versions.append(x["version"])
@@ -473,12 +480,10 @@ def _install_component(git_url):
 
 
 def _resolve_app_registry():
-    public_registry = "https://api.sheety.co/e559626ba514c7ba80caae1e38a8d4f4/lightningAppRegistry/apps"
-    registry = os.environ.get("LIGHTNING_APP_REGISTRY", public_registry)
+    registry = os.environ.get("LIGHTNING_APP_REGISTRY", LIGHTNING_APPS_PUBLIC_REGISTRY)
     return registry
 
 
 def _resolve_component_registry():
-    public_registry = "https://api.sheety.co/e559626ba514c7ba80caae1e38a8d4f4/lightningAppRegistry/components"
-    registry = os.environ.get("LIGHTNING_COMPONENT_REGISTRY", public_registry)
+    registry = os.environ.get("LIGHTNING_COMPONENT_REGISTRY", LIGHTNING_COMPONENT_PUBLIC_REGISTRY)
     return registry
