@@ -21,8 +21,10 @@ from lightning_app.core.constants import LIGHTNING_CLOUD_PROJECT_ID
 from lightning_app.runners.multiprocess import MultiProcessRuntime
 from lightning_app.testing.config import Config
 from lightning_app.utilities.cloud import _get_project
+from lightning_app.utilities.enum import CacheCallsKeys
 from lightning_app.utilities.imports import _is_playwright_available, requires
 from lightning_app.utilities.network import _configure_session, LightningClient
+from lightning_app.utilities.proxies import ProxyWorkRun
 
 if _is_playwright_available():
     import playwright
@@ -112,8 +114,13 @@ def run_work_isolated(work, *args, start_server: bool = False, **kwargs):
         start_server=start_server,
     ).dispatch()
     # pop the stopped status.
-    call_hash = work._calls["latest_call_hash"]
-    work._calls[call_hash]["statuses"].pop(-1)
+    call_hash = work._calls[CacheCallsKeys.LATEST_CALL_HASH]
+
+    if call_hash in work._calls:
+        work._calls[call_hash]["statuses"].pop(-1)
+
+    if isinstance(work.run, ProxyWorkRun):
+        work.run = work.run.work_run
 
 
 def browser_context_args(browser_context_args: Dict) -> Dict:
@@ -149,7 +156,7 @@ def run_app_in_cloud(app_folder: str, app_name: str = "app.py") -> Generator:
     # 3. Launch the application in the cloud from the Lightning CLI.
     with tempfile.TemporaryDirectory() as tmpdir:
         env_copy = os.environ.copy()
-        env_copy["PREPARE_LIGHTING"] = "1"
+        env_copy["PACKAGE_LIGHTNING"] = "1"
         shutil.copytree(app_folder, tmpdir, dirs_exist_ok=True)
         # TODO - add -no-cache to the command line.
         process = Popen(
@@ -193,7 +200,10 @@ def run_app_in_cloud(app_folder: str, app_name: str = "app.py") -> Generator:
             record_har_path=Config.har_location,
         )
         admin_page = context.new_page()
-        res = requests.post(Config.url + "/v1/auth/login", data=json.dumps(payload))
+        url = Config.url
+        if url.endswith("/"):
+            url = url[:-1]
+        res = requests.post(url + "/v1/auth/login", data=json.dumps(payload))
         token = res.json()["token"]
         print(f"The Lightning App Token is: {token}")
         print(f"The Lightning App user key is: {Config.key}")
@@ -217,13 +227,20 @@ def run_app_in_cloud(app_folder: str, app_name: str = "app.py") -> Generator:
                 [LIGHTNING_CLOUD_PROJECT_ID],
             )
         admin_page.goto(f"{Config.url}/{Config.username}/apps")
+
+        # Closing the Create Project dialog.
         try:
-            # Closing the Create Project modal
-            button = admin_page.locator('button:has-text("Cancel")')
+            project_dialog = admin_page.locator("text=Create a project")
+            project_dialog.wait_for(timeout=10 * 1000, state="visible")
+            print("'Create Project' dialog visible, closing it.")
+            project_name_input = admin_page.locator('input[type="text"]')
+            project_name_input.fill("Default Project")
+            button = admin_page.locator('button:has-text("Continue")')
             button.wait_for(timeout=3 * 1000)
             button.click()
-        except (playwright._impl._api_types.Error, playwright._impl._api_types.TimeoutError):
-            pass
+        except playwright._impl._api_types.TimeoutError:
+            print("'Create Project' dialog not visible, skipping.")
+
         admin_page.locator(f"text={name}").click()
         admin_page.evaluate(
             """data => {
